@@ -59,6 +59,7 @@ LegendVisitor::LegendVisitor()
 	view_y_ = 5; 
 	view_width_ = 90; 
 	view_height_=90;
+	positional_ = false;
 }
 
 
@@ -139,16 +140,20 @@ void LineEntry::rowBox(const PaperPoint& point, BasicGraphicsObjectContainer& ou
 {
 	double x = point.x();
 	double y = point.y();
-	double width = 1;
-	line_->push_back(PaperPoint(x- width, y));
-	line_->push_back(PaperPoint(x, y));
+
+	line_->push_back(PaperPoint(x-0.5, y));
+	line_->push_back(PaperPoint(x+0.5, y));
 	out.push_back(line_);
 }
 void LineEntry::columnBox(const PaperPoint& point, BasicGraphicsObjectContainer& out)
 {
-	set(point, out);
-}
+	double x = point.x();
+	double y = point.y();
 
+	line_->push_back(PaperPoint(x-15, y));
+	line_->push_back(PaperPoint(x+1, y));
+	out.push_back(line_);
+}
 void DoubleLineEntry::rowBox(const PaperPoint& point, BasicGraphicsObjectContainer& out)
 {
 	set(point, out);
@@ -174,7 +179,7 @@ void LegendVisitor::build()
 	current_->clear();
 	current_->blankIt();
 	current_->push_back(legend_);
-	
+	positions_.clear();
 
 	grid();
 
@@ -214,6 +219,7 @@ void LegendVisitor::build()
 		MagFont font(font_, font_style_, font_size_);
 		font.colour(*colour_);
 		(*entry)->font(font);
+		(*entry)->factor(symbol_factor_);
 		(*entry)->angle((orientation_/180.)*3.14);
 		(*entry)->borderColour(entry_border_ ? *entry_border_colour_ : Colour("automatic"));
 
@@ -1142,7 +1148,7 @@ void LegendVisitor::getReady()
 
 void XmlLegendVisitor::getReady()
 {
-	assert(BasicSceneObject::parent_);
+	ASSERT(BasicSceneObject::parent_);
 
 	Dimension bottom(bottom_, BasicSceneObject::parent_->absoluteWidth(), 0);
 	Dimension left(left_, BasicSceneObject::parent_->absoluteHeight(), 0);
@@ -1246,6 +1252,8 @@ void LegendEntry::set(const LegendVisitor& attributes)
 
 void SimpleSymbolEntry::set(const PaperPoint& point, BasicGraphicsObjectContainer& legend)
 {
+	symbol_->setHeight(symbol_->getHeight()*factor_);
+
 	symbol_->push_back(centreSymbolBox(point));
 	legend.push_back(symbol_);
 }
@@ -1273,6 +1281,7 @@ const string& LegendEntry::label() const
 }
 void SimpleSymbolEntry::rowBox(const PaperPoint& point, BasicGraphicsObjectContainer& legend)
 {
+
 	Polyline* box = new Polyline();
 	FillShadingProperties* shading = new FillShadingProperties();
 	box->setFillColour(colour());
@@ -1391,3 +1400,10 @@ void SimpleSymbolEntry::columnBox(const PaperPoint& point, BasicGraphicsObjectCo
 	box->setColour(colour);
 	legend.push_back(box);
 }
+
+SymbolEntry::~SymbolEntry() {} // { delete symbol_; }
+FlagEntry::~FlagEntry(){} //{ delete flag_; }
+BoxEntry::~BoxEntry() {} //{ delete box_; }
+ArrowEntry::~ArrowEntry() {} //{ delete arrow_; }
+DoubleLineEntry::~DoubleLineEntry() {} //{ { delete line1_; delete line2_; }
+LineEntry::~LineEntry() {} //{ delete line_;}
