@@ -4,7 +4,7 @@
 
  Licensed under the Apache License, Version 2.0 (the "License");
  you may not use this file except in compliance with the License.
- You may obtain a copy of the License at 
+ You may obtain a copy of the License at
 
     http://www.apache.org/licenses/LICENSE-2.0
 
@@ -38,7 +38,7 @@
 #include "BinaryObject.h"
 #include "TephiGrid.h"
 #include "TaylorGrid.h"
-#ifdef MAGICS_GRIB
+#ifdef HAVE_GRIB
 #include "GribDecoder.h"
 #endif
 #include "TableDecoder.h"
@@ -46,6 +46,7 @@
 #include "XYList.h"
 #include "EpsXmlInput.h"
 #include "WrepJSon.h"
+#include "GeoJSon.h"
 #include "SymbolPlotting.h"
 #include "Contour.h"
 #include "Wind.h"
@@ -65,7 +66,7 @@
 #include "MetaData.h"
 
 
-#ifdef MAGICS_SPOT
+#ifdef HAVE_SPOT
 #include "ClassicMtgDecoder.h"
 #include "EpsgramDecoder.h"
 #include "MetgramGraph.h"
@@ -76,15 +77,15 @@
 using namespace magics;
 
 XmlMagics::XmlMagics() : root_(0),
-	gribloop_(0), 
-	geographical_(true), 
+	gribloop_(0),
+	geographical_(true),
 	driversToSet_(true)
 {
 	writeMagLog("magml");
 
 	actions_["magics"] = &XmlMagics::magics;
 	actions_["page"] = &XmlMagics::page;
-	
+
 	actions_["mgb"] = &XmlMagics::binary;
 
 	actions_["text"] = &XmlMagics::text;
@@ -112,7 +113,7 @@ XmlMagics::XmlMagics() : root_(0),
 
 	actions_["wind"] = &XmlMagics::wind;
 	actions_["image"] = &XmlMagics::image;
-	actions_["symbol"] = &XmlMagics::symbol;	
+	actions_["symbol"] = &XmlMagics::symbol;
 	actions_["contour"] = &XmlMagics::contour;
 	actions_["histogram"] = &XmlMagics::histogram;
 	actions_["legend"] = &XmlMagics::legend;
@@ -133,8 +134,8 @@ XmlMagics::XmlMagics() : root_(0),
 
 	actions_["epsxml"] = &XmlMagics::epsxml;
 	actions_["wrepjson"] = &XmlMagics::wrepjson;
+	actions_["geojson"] = &XmlMagics::geojson;
 
-	
 	actions_["epsbufr"] = &XmlMagics::epsbufr;
 	actions_["epsgraph"] = &XmlMagics::epsgraph;
 	actions_["epsgram"] = &XmlMagics::epsgram;
@@ -158,20 +159,20 @@ XmlMagics::XmlMagics() : root_(0),
 }
 
 
-XmlMagics::~XmlMagics() 
+XmlMagics::~XmlMagics()
 {
 }
- 
+
 /*!
  Class information are given to the output-stream.
-*/		
+*/
 void XmlMagics::print(ostream& out)  const
 {
 	out << "XmlMagics[";
 	out << "]";
 }
 
-void XmlMagics::execute(XmlTree& tree) 
+void XmlMagics::execute(XmlTree& tree)
 {
 	{
 
@@ -182,21 +183,21 @@ void XmlMagics::execute(XmlTree& tree)
 		MagLog::debug() << e.what() << endl;
 	}
 
-	if ( driversToSet_ ) 
+	if ( driversToSet_ )
 		output_.set(drivers_);
 
-	assert(root_);
+	ASSERT(root_);
 
 	root_->execute();
 
-	if ( root_->scalingFactor() != 1)  
+	if ( root_->scalingFactor() != 1)
 		drivers_.setOutputWidth(root_->scalingFactor());
 
 
 	drivers_.setDriversWidth(root_->absoluteWidth());
 	drivers_.setDriversHeight(root_->absoluteHeight());
 
-	{ 
+	{
 		Timer timer("drivers", "rendering of the graphical tree");
 		drivers_.openDrivers();
 		drivers_.dispatch(root_->root());
@@ -206,13 +207,13 @@ void XmlMagics::execute(XmlTree& tree)
 	}
 	MetaDataVisitor::collect();
 	//root_->metadata(meta);
-	/* later 
+	/* later
 		std::map<string, string>::const_iterator filename = meta.find("filename");
 		if ( filename != meta.end() && !filename->second.empty()) {
 			ofstream file (filename->second.c_str());
-		
+
 			for (std::map<string, string>::const_iterator d = meta.begin(); d != meta.end(); ++d) {
-				if ( d != filename ) 
+				if ( d != filename )
 	                file << d->first << " = " << d->second << "; " << endl;
 	        }
 		}
@@ -225,12 +226,12 @@ void XmlMagics::execute(XmlTree& tree)
 
 void XmlMagics::execute(const string& file, std::map<string, string>& )
 {
-	
+
 	XmlReader parser(true);
-	XmlTree tree;	
-	ParameterManager::set(string("layout"), string("magml")); 
+	XmlTree tree;
+	ParameterManager::set(string("layout"), string("magml"));
 	try {
-		parser.interpret(file, &tree);		
+		parser.interpret(file, &tree);
 		execute(tree);
 	}
 	catch (MagicsException& e) {
@@ -241,31 +242,31 @@ void XmlMagics::execute(const string& file, std::map<string, string>& )
 void XmlMagics::display(const string& file)
 {
 	XmlReader parser(true);
-	XmlTree tree;	
+	XmlTree tree;
 
 	try {
-		parser.interpret(file, &tree);		
+		parser.interpret(file, &tree);
 		tree.visit(*this);
 	}
 	catch (MagicsException& e) {
 			MagLog::debug() << e.what() << endl;
 	}
-	
-	if ( driversToSet_ ) 
+
+	if ( driversToSet_ )
 		output_.set(drivers_);
 
-	assert(root_);
+	ASSERT(root_);
 	root_->getReady();
 	drivers_.setDriversWidth(root_->absoluteWidth());
 	drivers_.setDriversHeight(root_->absoluteHeight());
-	
+
 	root_->execute();
 	drivers_.openDrivers();
 	drivers_.dispatch(root_->root());
 
 	drivers_.closeDrivers();
 }
-	
+
 void XmlMagics::visit(const XmlNode& node)
 {
 	std::map<string, Action>::iterator action = actions_.find(node.name());
@@ -280,7 +281,7 @@ void XmlMagics::visit(const XmlNode& node)
 
 void XmlMagics::magics(const XmlNode& node)
 {
-	ParameterManager::set(string("layout"), string("magml")); 
+	ParameterManager::set(string("layout"), string("magml"));
 	const float version_ = 3.0;
 	MagLog::debug() << " You are using the " << fixed << setprecision(1) << version_ << " version of the magml interpreter\n";
 	string version = node.getAttribute("version");
@@ -295,12 +296,12 @@ void XmlMagics::magics(const XmlNode& node)
 	sv >> v;
 	if ( v < version_ )
 	{
-		MagLog::error() << " The version defined in the file is " << fixed << setprecision(1) << v 
+		MagLog::error() << " The version defined in the file is " << fixed << setprecision(1) << v
 		             << "\n Compatibilty issue: check your magml file and update the version number" << endl;
 		return;
 	}
 	string method = node.getAttribute("method") ;
-	
+
 	if  ( method == "wrep" )
 		root_ = new  WrepRootSceneNode();
 	else if  ( method == "legacy" )
@@ -376,8 +377,8 @@ void XmlMagics::legend(const XmlNode& node)
 {
 	LegendVisitor* legend = new XmlLegendVisitor();
 	legend->set(node);
-	
-	top()->legend(legend);	
+
+	top()->legend(legend);
 	node.visit(*this);
 }
 
@@ -386,7 +387,7 @@ void XmlMagics::text(const XmlNode& node)
 	XmlTextVisitor* text = new XmlTextVisitor();
 	text->set(node);
 	top()->text(text);
-	
+
 	node.visit(*this);
 }
 
@@ -406,21 +407,21 @@ void XmlMagics::map(const XmlNode& node)
 }
 
 void XmlMagics::binary(const XmlNode& node)
-{	
+{
 	BinaryObject* binary = new BinaryObject();
 	binary->set(node);
 	top()->push_back(binary);
 }
 
 void XmlMagics::coastlines(const XmlNode& node)
-{	
+{
 	Coastlines* coast = new Coastlines();
 	coast->set(node);
 	top()->push_back(coast);
 }
 
 void XmlMagics::taylor(const XmlNode& node)
-{	
+{
 	TaylorGrid* grid = new TaylorGrid();
 	grid->set(node);
 	top()->push_back(grid);
@@ -432,26 +433,26 @@ void XmlMagics::tephigrid(const XmlNode& node)
 	top()->push_back(grid);
 }
 void XmlMagics::horizontalAxis(const XmlNode& node)
-{	
+{
 	HorizontalAxis* axis = new HorizontalAxis();
 	axis->set(node);
 	top()->push_back(axis);
 }
 
 void XmlMagics::verticalAxis(const XmlNode& node)
-{	
+{
 	VerticalAxis* axis = new VerticalAxis();
 	axis->set(node);
 	top()->push_back(axis);
 }
 
 void XmlMagics::cartesian(const XmlNode&)
-{	
+{
 	geographical_ = false;
 }
 
 void XmlMagics::geographical(const XmlNode&)
-{	
+{
 	geographical_ = true;
 }
 
@@ -462,7 +463,7 @@ void XmlMagics::layer(const XmlNode& node)
 		VisualAction* action = new VisualAction();
 		action->set(node);
 		top()->push_back(action);
-		push(action);	
+		push(action);
 	}
 	else {
 		VisualAction* action = new VisualAction();
@@ -475,7 +476,7 @@ void XmlMagics::layer(const XmlNode& node)
 	pop();
 }
 
-#ifdef MAGICS_GRIB
+#ifdef HAVE_GRIB
 GribDecoder* grib_handler;
 
 void XmlMagics::gribloop(const XmlNode& node)
@@ -493,10 +494,10 @@ void XmlMagics::gribloop(const XmlNode& node)
 }
 
 
-void XmlMagics::splitinloop(const XmlNode& ) 
+void XmlMagics::splitinloop(const XmlNode& )
 {
 	/* later!
-	assert(gribloop_);
+	ASSERT(gribloop_);
 
 	LayerNode* layer = new LayerNode();
 	layer->set(node);
@@ -509,8 +510,8 @@ void XmlMagics::splitinloop(const XmlNode& )
 }
 
 void XmlMagics::gribinloop(const XmlNode&)
-{	
-	assert(gribloop_);
+{
+	ASSERT(gribloop_);
 	top()->data(gribloop_->current());
 }
 
@@ -529,7 +530,7 @@ void XmlMagics::gribloop(const XmlNode&)
 }
 
 void XmlMagics::gribinloop(const XmlNode&)
-{	
+{
 	MagLog::warning() <<" Attempt to call GribInLoop but GRIB support is disabled!"<< endl;
 }
 
@@ -542,7 +543,7 @@ void XmlMagics::grib(const XmlNode&)
 
 #include "GeoPointsDecoder.h"
 void XmlMagics::geopoints(const XmlNode& node)
-{	
+{
 	GeoPointsDecoder* geo = new GeoPointsDecoder();
 	geo->set(node);
 	top()->data(geo);
@@ -550,7 +551,7 @@ void XmlMagics::geopoints(const XmlNode& node)
 
 #include "MapGenDecoder.h"
 void XmlMagics::mapgen(const XmlNode& node)
-{	
+{
 	if (geographical_) {
 		MapGenDecoder* mapgen = new MapGenDecoder();
 		mapgen->set(node);
@@ -564,7 +565,7 @@ void XmlMagics::mapgen(const XmlNode& node)
 }
 
 void XmlMagics::xyinput(const XmlNode& node)
-{	
+{
 	if (geographical_) {
 			XYList* list = new XYList();
 			list->set(node);
@@ -588,7 +589,7 @@ void XmlMagics::input(const XmlNode& node)
 
 #include "GraphPlotting.h"
 void XmlMagics::graph(const XmlNode& node)
-{	
+{
 	GraphPlotting* graph =  new GraphPlotting();
 	graph->set(node);
 	top()->visdef(graph);
@@ -610,17 +611,17 @@ void XmlMagics::histogram(const XmlNode& node)
 
 ***************************************************************************/
 
-#ifdef MAGICS_ODB
+#ifdef HAVE_ODB
 #include "OdaDecoder.h"
 #endif
 
 void XmlMagics::odb(const XmlNode& node)
 {
-#ifdef MAGICS_ODB
+#ifdef HAVE_ODB
 	OdaGeoDecoder* odb = new OdaGeoDecoder();
 	odb->set(node);
 	top()->data(odb);
-#else 
+#else
 	MagLog::warning() << "ODB support is NOT enabled!\n";
 #endif
 
@@ -630,8 +631,8 @@ void XmlMagics::odb(const XmlNode& node)
 
 
 void XmlMagics::efigram(const XmlNode& node)
-{	
-#ifdef MAGICS_SPOT
+{
+#ifdef HAVE_SPOT
 	EfigramDecoder* efi = new EfigramDecoder();
 	efi->set(node);
 	top()->data(efi);
@@ -639,14 +640,14 @@ void XmlMagics::efigram(const XmlNode& node)
 }
 
 void XmlMagics::cdfgraph(const XmlNode& node)
-{	
+{
 	CdfGraph* cdf = new CdfGraph();
 	cdf->set(node);
 	top()->visdef(cdf);
 }
 
 void XmlMagics::efigraph(const XmlNode& node)
-{	
+{
 	EfiGraph* efi = new EfiGraph();
 	efi->set(node);
 	top()->visdef(efi);
@@ -654,22 +655,22 @@ void XmlMagics::efigraph(const XmlNode& node)
 
 
 void XmlMagics::epsplume(const XmlNode& node)
-{	
+{
 	EpsPlume* plume = new EpsPlume();
 	plume->set(node);
 	top()->visdef(plume);
 }
 
 void XmlMagics::epsdirection(const XmlNode& node)
-{	
+{
 	EpsDirection* direction = new EpsDirection();
 	direction->set(node);
 	top()->visdef(direction);
 }
 
 void XmlMagics::metgram(const XmlNode& node)
-{	
-#ifdef MAGICS_SPOT
+{
+#ifdef HAVE_SPOT
 	ClassicMtgDecoder* metgram = new ClassicMtgDecoder();
 	metgram->set(node);
 	top()->data(metgram);
@@ -677,8 +678,8 @@ void XmlMagics::metgram(const XmlNode& node)
 }
 
 void XmlMagics::metgraph(const XmlNode& node)
-{	
-#ifdef MAGICS_SPOT
+{
+#ifdef HAVE_SPOT
 	MetgramGraph* metgraph = new MetgramGraph();
 	metgraph->set(node);
 	top()->visdef(metgraph);
@@ -687,8 +688,8 @@ void XmlMagics::metgraph(const XmlNode& node)
 
 
 void XmlMagics::epsgram(const XmlNode& node)
-{	
-#ifdef MAGICS_SPOT
+{
+#ifdef HAVE_SPOT
 	EpsgramDecoder* eps = new EpsgramDecoder();
 	eps->set(node);
 	top()->data(eps);
@@ -696,26 +697,32 @@ void XmlMagics::epsgram(const XmlNode& node)
 }
 
 void XmlMagics::epsxml(const XmlNode& node)
-{	
+{
 	EpsXmlInput* eps = new EpsXmlInput();
 	eps->set(node);
 	top()->data(eps);
 }
 void XmlMagics::wrepjson(const XmlNode& node)
-{	
+{
 
 	WrepJSon* wrep = new WrepJSon();
 	wrep->set(node);
 	top()->data(wrep);
 }
+void XmlMagics::geojson(const XmlNode& node)
+{
 
+	GeoJSon* geo = new GeoJSon();
+	geo->set(node);
+	top()->data(geo);
+}
 
-#ifdef MAGICS_BUFR
+#ifdef HAVE_BUFR
 #include "EpsBufr.h"
 #endif
 void XmlMagics::epsbufr(const XmlNode& node)
-{	
-#ifdef MAGICS_BUFR
+{
+#ifdef HAVE_BUFR
 	EpsBufr* eps = new EpsBufr();
 	eps->set(node);
 	top()->data(eps);
@@ -723,28 +730,28 @@ void XmlMagics::epsbufr(const XmlNode& node)
 }
 
 void XmlMagics::epsgraph(const XmlNode& node)
-{	
+{
 	EpsGraph* epsgraph = new EpsGraph();
 	epsgraph->set(node);
 	top()->visdef(epsgraph);
 }
 
 void XmlMagics::epswave(const XmlNode& node)
-{	
+{
 	EpsWave* eps = new EpsWave();
 	eps->set(node);
 	top()->visdef(eps);
 }
 
 void XmlMagics::epswind(const XmlNode& node)
-{	
+{
 	EpsWind* epswind = new EpsWind();
 	epswind->set(node);
 	top()->visdef(epswind);
 }
 
 void XmlMagics::epscloud(const XmlNode& node)
-{	
+{
 	EpsCloud* epscloud = new EpsCloud();
 	epscloud->set(node);
 	top()->visdef(epscloud);
@@ -756,18 +763,18 @@ void XmlMagics::epsbar(const XmlNode& node)
 	top()->visdef(epsbar);
 }
 void XmlMagics::epsshading(const XmlNode& node)
-{	
+{
 	EpsShade* eps = new EpsShade();
 	eps->set(node);
 	top()->visdef(eps);
 }
 
-#ifdef MAGICS_NETCDF
+#ifdef HAVE_NETCDF
 #include "NetcdfDecoder.h"
 #endif
 void XmlMagics::netcdf(const XmlNode& node)
 {
-#ifdef MAGICS_NETCDF
+#ifdef HAVE_NETCDF
 	if ( geographical_ ) {
 		NetcdfDecoder* netcdf = new NetcdfDecoder();
 		netcdf->set(node);
@@ -790,7 +797,7 @@ void XmlMagics::table(const XmlNode& node)
 
 #include "InputMatrix.h"
 void XmlMagics::matrix(const XmlNode& node)
-{	
+{
 		//MatrixTestDecoder* matrix = new MatrixTestDecoder();
 		//matrix->set(node);
 		if ( geographical_ ) {
@@ -821,7 +828,7 @@ void XmlMagics::polyline(const XmlNode& node)
 
 
 void  XmlMagics::symbol(const XmlNode& node)
-{	
+{
 	if ( geographical_ ) {
 		SymbolPlotting* symbol =  new SymbolPlotting();
 		symbol->set(node);
@@ -864,7 +871,7 @@ void XmlMagics::import(const XmlNode& node)
 
 }
 void XmlMagics::wind(const XmlNode& node)
-{	
+{
 	if ( geographical_ ) {
 		Wind* wind =  new Wind();
 		wind->set(node);
@@ -873,7 +880,7 @@ void XmlMagics::wind(const XmlNode& node)
 	else {
 		MagLog::warning() << " wind not yet implemented for cartesian system" << endl;
 	}
-#ifdef MAGICS_GRIB
+#ifdef HAVE_GRIB
 	if ( gribloop_ ) gribloop_->next();
 #endif
 }
