@@ -92,7 +92,7 @@ public:
 	}
 };
 
-#ifdef MAGICS_CAIRO
+#ifdef HAVE_CAIRO
 template<>
 class MagTranslator<cairo_t*, cairo_t*> {
 public:
@@ -232,7 +232,28 @@ public:
 	}
 };
 
+template<>
+class MagTranslator<string, longintarray> {
+public:
+	longintarray operator()(const string& value)
+	{
+		longintarray array;
+		vector<string> list;
+		Tokenizer tokenizer("/");
+		tokenizer(value, list);
 
+		for(vector<string>::const_iterator item = list.begin(); item != list.end(); ++item) {
+			array.push_back(atoi((*item).c_str()));
+		}
+		return array;
+	}
+	longintarray magics(const string& param)
+	{
+		longintarray from;
+		ParameterManager::get(param, from);
+		return from;
+	}
+};
 template<>
 class MagTranslator<intarray, intarray> {
 public:
@@ -247,6 +268,20 @@ public:
 		return (*this)(from);
 	}
 };
+template<>
+class MagTranslator<longintarray, longintarray> {
+public:
+	longintarray operator()(longintarray value)
+	{
+		return value;
+	}
+	longintarray magics(const string& param)
+	{
+		longintarray from;
+		ParameterManager::get(param, from);
+		return (*this)(from);
+	}
+};
 
 template<>
 class MagTranslator<const string&, const string&> {
