@@ -332,10 +332,7 @@ public :
     
     
     MatrixHandler* getReady(const Transformation& transformation) {
-    	if ( !&matrix_ )
-    		return 0;
     	return matrix_.getReady(transformation);
-
     }
     
 protected:    
@@ -884,13 +881,13 @@ protected :
 	int columnIndex(int column) const
 	{
 		map<int, int>::const_iterator index = columnIndex_.find(column);
-		assert( index != columnIndex_.end() );
+		ASSERT( index != columnIndex_.end() );
 		return index->second;
 	}
 	int rowIndex(int row) const
 	{
 		map<int, int>::const_iterator index = rowIndex_.find(row);
-		assert( index != rowIndex_.end() );
+		ASSERT( index != rowIndex_.end() );
 		return index->second;
 	}
 	int  frequencyRow_;
