@@ -61,6 +61,8 @@ void OutputHandler::set(const XmlNode& node, DriverManager& magics)
 			lineSpacing_ = 0.8;
 		else if (node.name() == "pdf" && factories_.empty() )
 			lineSpacing_ = 0.8;
+		else if (node.name() == "mgb" && factories_.empty() )
+				lineSpacing_ = 0.8;
 		else
 			lineSpacing_ = 1.2;
 
@@ -91,7 +93,7 @@ static SimpleObjectMaker<PS_EpsOutputFactory, OutputFactory> eps("eps");
 static SimpleObjectMaker<PS_PdfOutputFactory,  OutputFactory> ps_pdf("ps_pdf");
 
 #ifdef MAGICS_RASTER
-#ifdef MAGICS_CAIRO
+#ifdef HAVE_CAIRO
 static SimpleObjectMaker<GD_PngOutputFactory, OutputFactory> gdpng("gd_png");
 #else
 static SimpleObjectMaker<GD_PngOutputFactory, OutputFactory> gdpng("png");
@@ -105,17 +107,18 @@ static SimpleObjectMaker<SVG_SvgOutputFactory, OutputFactory> svg("svg");
 
 static SimpleObjectMaker<BinaryOutputFactory, OutputFactory> binary("mgb");
 
-#ifdef MAGICS_CAIRO
+#ifdef HAVE_CAIRO
 static SimpleObjectMaker<CAIRO_PngOutputFactory,    OutputFactory> png("png");
 static SimpleObjectMaker<CAIRO_PdfOutputFactory,    OutputFactory> pdf("pdf");
-static SimpleObjectMaker<CAIRO_XOutputFactory,      OutputFactory> x("x");
+//static SimpleObjectMaker<CAIRO_XOutputFactory,      OutputFactory> x("x");
 static SimpleObjectMaker<CAIRO_CairoOutputFactory,  OutputFactory> cairo("cairo");
 static SimpleObjectMaker<CAIRO_SvgOutputFactory,    OutputFactory> csvg("cairo_svg");
 static SimpleObjectMaker<CAIRO_PsOutputFactory,     OutputFactory> cps("cairo_ps");
 static SimpleObjectMaker<CAIRO_EpsOutputFactory,    OutputFactory> ceps("cairo_eps");
-#ifdef MAGICS_GEOTIFF
+#ifdef HAVE_GEOTIFF
 static SimpleObjectMaker<CAIRO_GeoTiffOutputFactory,OutputFactory> geotiff("geotiff");
 #endif
 #endif
 
 static SimpleObjectMaker<KML_KmlOutputFactory, OutputFactory> kml("kml");
+static SimpleObjectMaker<GEOJSON_GeoJsonOutputFactory, OutputFactory> geojson("geojson");
