@@ -45,7 +45,7 @@ Tephigram::Tephigram()
 /*!
   \brief Destructor
 */
-Tephigram::~Tephigram() 
+Tephigram::~Tephigram()
 {
 }
 
@@ -58,25 +58,29 @@ void Tephigram::print(ostream& out) const
 #define sinus  -0.7071
 #define cosinus  0.7071
 static double maxpcx;
-void Tephigram::init()  
+void Tephigram::init()
 {
-	if ( x_min_ == 0 && x_max_ == 100 ) {
-		x_min_ = -20;
-		x_max_ =40;
-	}
 
-	if ( y_min_ == 0 && y_max_ == 100 ) {
-			y_min_ = 1060.;
-			y_max_ = 200;
+	if ( x_min_ == 0 && x_max_ == 100 ) {
+			x_min_ = -90;
+			x_max_ = 50;
 		}
 
-	double tmin = x_min_;
-	double thmin= magics::theta(tmin+273.15, y_min_*100.)-273.15;
+		if ( y_min_ == 0 && y_max_ == 100 ) {
+				y_min_ = 1060.;
+				y_max_ = 200;
+			}
 
-	double thmax = magics::theta(tmin+273.15, y_max_*100.)-273.15;
-	double tmax = temperatureFromTheta(thmax+273.15,  y_max_*100. ) -273.15;
+		vector<double> x, y;
 
 
+		double tmin = (x_min_ + x_max_)/2.;
+		double pmin = std::max(y_min_, y_max_);
+		double pmax = std::min(y_min_, y_max_);
+
+		double thmin= magics::theta(tmin+273.15, pmin*100.)-273.15;
+		double thmax = magics::theta(tmin+273.15, pmax*100.)-273.15;
+		double tmax = temperatureFromTheta(thmax+273.15,  pmax*100. ) -273.15;
 	minPCX_ = ((tmin * cosinus) - (thmin * sinus) );
 	minPCY_ = (tmin * sinus) + (thmin * cosinus);
 	maxPCX_ = ((tmax * cosinus) - (thmax * sinus));
@@ -86,7 +90,7 @@ void Tephigram::init()
 	maxpcx = maxPCX_;
 
 	MagLog::dev() << "useful in tephi " << maxpcx << endl;
-	maxPCX_ += (maxPCX_ - minPCX_)*0.25;
+	maxPCX_ += (maxPCX_ - minPCX_)*(annotation_width_/100.);
 	MagLog::dev() << "set in tephi in grid " << maxpcx << endl;
 
 
@@ -115,11 +119,16 @@ void TephiInfo::init()
 const double KAPPA=0.285611;
 PaperPoint Tephigram::operator()(const UserPoint& xy)  const
 {
+
+
+	double p = (same(xy.y(), 0) ) ? 1. : xy.y();
 	if (  xy.x() >= 1000 ) {// x = x
 	// y = p
-		double coefficient = pow(100000./(xy.y()*100),KAPPA);
+
+
+		double coefficient = pow(100000./(p*100),KAPPA);
 		double y = (maxpcx+(273.15*(cosinus-sinus)))*((sinus + (coefficient*cosinus)))/(cosinus -(coefficient*sinus)) - 2713.15*(sinus+cosinus);
-		MagLog::dev() << xy.y() << "-->" << y << "??? " << minPCY_ << "<<" <<  maxPCY_<< endl;
+		MagLog::dev() << p << "-->" << y << "??? " << minPCY_ << "<<" <<  maxPCY_<< endl;
 		double x =  (maxPCX_ - maxpcx)*(xy.x()-1000.) + maxpcx;
 		MagLog::dev() << x << endl;
 		return PaperPoint(x, y, xy.value());
@@ -127,7 +136,8 @@ PaperPoint Tephigram::operator()(const UserPoint& xy)  const
 	// UserPoint X = temperature in deg Y = Pressure in hPa
 	// First we calculate theta and we rotate!
 	double tempe = xy.x();
-	double theta = magics::theta(tempe+273.15, (xy.y())*100.)-273.15;
+
+	double theta = magics::theta(tempe+273.15, p*100.)-273.15;
 	double x = ((tempe * cosinus) - (theta * sinus) );
 	double y = (tempe * sinus) + (theta * cosinus);
 
@@ -169,8 +179,28 @@ bool Tephigram::needShiftedCoastlines()  const
 {
 	return false;
 }
+void Tephigram::setMinMaxX(double min, double max)
+{
+	if ( min > 1000 || max > 1000) return;
+	setMinX(min);
+	setMaxX(max);
+	init();
+}
 
-void Tephigram::aspectRatio(double& width, double& height)  
+void Tephigram::setMinMaxY(double min, double max)
+{
+	// Careful, Tephigram are in pressure levels...
+	if ( min < 50.) {
+		MagLog::warning() << " Top Pressure reset to 50." << endl;
+		min = 50.;
+	}
+
+
+	setMinY(max);
+	setMaxY(min);
+	init();
+}
+void Tephigram::aspectRatio(double& width, double& height)
 {
 
 
@@ -238,24 +268,28 @@ double Tephigram::getMaxY()  const
 	return y_max_;
 }
 
-void Tephigram::setMinX(double x)  
+void Tephigram::setMinX(double x)
 {
-	x_min_ = x;
+	if ( x < x_min_ )
+		x_min_ = x;
 }
 
-void Tephigram::setMinY(double y)  
+void Tephigram::setMinY(double y)
 {
-	y_min_ = y;
+	if ( y > y_min_ )
+		y_min_ = y;
 }
 
-void Tephigram::setMaxX(double x)  
+void Tephigram::setMaxX(double x)
 {
-	x_max_ = x;
+	if ( x > x_max_ )
+		x_max_ = x;
 }
 
-void Tephigram::setMaxY(double y)  
+void Tephigram::setMaxY(double y)
 {
-	y_max_ = y;
+	if ( y < y_max_ )
+		y_max_ = y;
 }
 
 double Tephigram::getMinPCX()  const
@@ -325,7 +359,7 @@ void Tephigram::setDefinition(const string& json)
 
 		XmlNode node = **helper.tree_.firstElement();
 
-		node.name("tephigram");
+		node.name("Tephigram");
 
 
 		set(node);
@@ -344,7 +378,7 @@ void toxml2(string& out, const map<string, string>& def)
 void Tephigram::getNewDefinition(const UserPoint& ll, const UserPoint& ur, string& out) const
 {
 	map<string, string> def;
-	def["subpage_map_projection"] = "tephigram";
+	def["subpage_map_projection"] = "Tephigram";
 
 	def["x_min"]= tostring(ll.x_);
 			def["x_max"]= tostring(ur.x_);
