@@ -45,6 +45,18 @@ class Transformation;
 
 class RasterData;
 
+struct Index
+    {
+        int    index_;
+        double lat_;
+        double lon_;
+        bool   used_;
+        Index(int index, double lat, double lon) : index_(index), lat_(lat), lon_(lon), used_(false) {}
+        void print()
+        {
+        	cout << "[" << lat_ << ", " << lon_ << "]" << endl;
+        }
+    };
 
 class GribInterpretor  {
 
@@ -71,12 +83,31 @@ public:
 
     void interpolate(const GribDecoder& grib, Matrix& matrix) const;
 
+    virtual void  index(const GribDecoder& grib);
+    virtual void  new_index(const GribDecoder& grib);
+    
+    virtual int nearest(double, double, double&, double&);
+    Index nearest(double, double);
+    double west_;
+    double east_;
+
+    vector<vector<Index> > helper_;
     
 protected:
      //! Method to print string about this class on to a stream of type ostream (virtual).
 	 virtual void print(ostream& out) const { out <<  "GribInterpretor" << endl; }
+	 map<double, map<double, int> > index_;
+    int indexLon_;
+    int indexLat_;
+    double indexStep_;
+    double minlat_;
+    double maxlat_;
+    double minlon_;
+    double maxlon_;
+
 
 private:
+
     //! Copy constructor - No copy allowed
 	GribInterpretor(const GribInterpretor&);
     //! Overloaded << operator to copy - No copy allowed
