@@ -48,10 +48,13 @@ public:
 	virtual void interpretAsRaster(const GribDecoder&, RasterData&, const Transformation&) const;
     virtual void latitudes(const GribDecoder&, vector<double>&) const;
     virtual double longitudeIncrement(const GribDecoder&) const;
+    void  index(const GribDecoder& grib);
+
 protected:
      //! Method to print string about this class on to a stream of type ostream (virtual).
 	 virtual void print(ostream&) const; 
 
+
 private:
     //! Copy constructor - No copy allowed
 	GribRegularInterpretor(const GribRegularInterpretor&);
@@ -75,6 +78,7 @@ public:
 	void interpretAsMatrix(const GribDecoder&, Matrix**) const; 
 	void interpretAsMatrix(const GribDecoder&, Matrix**, const Transformation&) const; 
 	void interpretAsRaster(const GribDecoder&, RasterData&, const Transformation&) const;
+	void  index(const GribDecoder& grib);
 	
 protected:
      //! Method to print string about this class on to a stream of type ostream (virtual).
@@ -152,6 +156,8 @@ public:
 	UserPoint unrotate(double lat, double lon) const;
 	void interpretAsMatrix(const GribDecoder&, Matrix**) const; 
 	PaperPoint reference(const GribDecoder&, const Transformation&);
+	double XResolution(const GribDecoder& grib) const;
+
 protected:
      //! Method to print string about this class on to a stream of type ostream (virtual).
 	 virtual void print(ostream&) const; 
