@@ -55,9 +55,9 @@ bool NetcdfGeoMatrixInterpretor::interpretAsMatrix(Matrix** data)
    
 	Netcdf netcdf(path_, dimension_method_);
 
-	double missing_value = netcdf.getDefaultMissing(field_);
 
-	missing_value = netcdf.getVariableAttribute(field_, missing_attribute_, missing_value);
+
+	double missing_value = netcdf.getMissing(field_, missing_attribute_);
 
 
 	// get the data ...
@@ -92,6 +92,7 @@ bool NetcdfGeoMatrixInterpretor::interpretAsMatrix(Matrix** data)
 			for (vector<double>::iterator d = data.begin(); d != data.end(); ++d ) {
 				if ( !isnan(*d) ) {
 					matrix_->push_back(*d);
+
 				}
 				else 
 					matrix_->push_back(missing_value);
@@ -209,7 +210,7 @@ void NetcdfGeoMatrixInterpretor::visit(ValuesCollector& vcp,PointsList&)
 {	
 	vcp.setCollected(true);
 	
-  	assert(matrix_); 
+  	ASSERT(matrix_); 
   	const Transformation& transformation = vcp.transformation();
   	MatrixHandler* box =  transformation.prepareData(*matrix_);
 	for (ValuesCollector::iterator point =  vcp.begin(); point != vcp.end(); ++point) {
@@ -217,4 +218,58 @@ void NetcdfGeoMatrixInterpretor::visit(ValuesCollector& vcp,PointsList&)
 	}
 }
 
+void NetcdfGeoMatrixInterpretor::customisedPoints(const Transformation& transformation, const std::set<string>&, CustomisedPointsList& out, int thinning)
+{
+	Netcdf netcdf(path_, dimension_method_);
 
+		// get the data ...
+		try
+		{
+			vector<double> latitudes;
+			vector<double> longitudes;
+			vector<double> xcomponent;
+			vector<double> ycomponent;
+			vector<double> colcomponent;
+			map<string, string> first, last;
+			setDimensions(dimension_, first, last);
+			double missing_value = missing(netcdf);
+
+			netcdf.get(x_component_, xcomponent, first, last);
+			netcdf.get(y_component_, ycomponent, first, last);
+			if ( !colour_component_.empty() )
+				netcdf.get(colour_component_, colcomponent, first, last);
+			netcdf.get(longitude_, longitudes, first, last);
+			netcdf.get(latitude_, latitudes, first, last);
+			unsigned int val = 0;
+
+			for (unsigned int  lat  =0 ; lat < latitudes.size(); lat+=thinning) {
+				for ( unsigned int lon = 0; lon < longitudes.size(); lon+=thinning) {
+					val = (lat* longitudes.size() + lon);
+					if ( val >= xcomponent.size() ) return;
+					if ( val >= ycomponent.size() ) return;
+					if ( !colour_component_.empty() )
+						if ( val >= colcomponent.size() ) return;
+					if ( same(xcomponent[val], missing_value ) ) continue;
+					if ( same(ycomponent[val], missing_value ) ) continue;
+					vector<UserPoint> points;
+					transformation.populate(longitudes[lon], latitudes[lat], 0, points);
+					for (vector<UserPoint>::iterator  pt = points.begin(); pt != points.end(); ++pt ) {
+						CustomisedPoint* point = new CustomisedPoint(pt->x_, pt->y_, "");
+							(*point)["x_component"] = xcomponent[val];
+						(*point)["y_component"] = ycomponent[val];
+						if ( !colour_component_.empty() )
+							(*point)["colour_component"] = colcomponent[val];
+						out.push_back(point);
+					}
+				}
+			}
+	 		MagLog::dev()<< "everything ok" << endl;
+		}
+		catch (MagicsException& e)
+		{
+			MagLog::error() << e << "\n";
+
+		}
+
+
+}
