@@ -74,7 +74,7 @@ public:
     virtual void statsData(map<string,vector<double> >&);
     virtual void visit(MetaDataCollector&);
     virtual void visit(ValuesCollector&,PointsList&); 
-    void customisedPoints(const Transformation&, const std::set<string>&, CustomisedPointsList&);
+    void customisedPoints(const Transformation&, const std::set<string>&, CustomisedPointsList&, int);
 protected:
      //! Method to print string about this class on to a stream of type ostream (virtual).
 	 virtual void print(ostream&) const; 
