@@ -38,6 +38,8 @@ public:
 
 	void execute(MagRequest&);
 
+	static void decode(MagRequest&, const string&);
+
 	void registerObserver(MagicsObserver* observer) { observers_.push_back(observer); }
 	void unregisterObserver(MagicsObserver* observer);
 	//! Notify drivers about an event (GUI -> Qt)
@@ -82,13 +84,14 @@ protected:
 	bool oldcoastlines(magics::MagRequest&);
 	bool axis(magics::MagRequest&);
 	bool grib(magics::MagRequest&);
+	bool geojson(magics::MagRequest&);
 	bool gribloop(magics::MagRequest&);
 	bool rasterloop(magics::MagRequest&);
 	bool dataloop(magics::MagRequest&);
 	bool bufr(magics::MagRequest&);
 	bool visdef(magics::MagRequest&);
 	
-#ifdef MAGICS_ODB	
+#ifdef HAVE_ODB
 	bool geoodb(magics::MagRequest&);
 	bool xyodb(magics::MagRequest&);
 #endif
@@ -123,6 +126,7 @@ protected:
 	bool pngdriver(magics::MagRequest&);
 	bool svgdriver(magics::MagRequest&);
 	bool kmldriver(magics::MagRequest&);  
+	bool geojsondriver(magics::MagRequest&);  
 	bool psdriver(magics::MagRequest&);
 	bool epsdriver(magics::MagRequest&);
     
