@@ -40,7 +40,7 @@
 #include <climits>
 
 // do the export restriction only if NOT for Metview
-#ifndef MAGICS_METVIEW
+#ifndef HAVE_METVIEW
 
 #ifdef WIN32
   #define MAGICS_IMPORT __declspec(dllimport)
@@ -175,6 +175,7 @@ public:
 
 typedef magvector<string>	stringarray;
 typedef magvector<int>		intarray;
+typedef magvector<long int>		longintarray;
 typedef magvector<double>	doublearray;
 typedef magvector<double>	floatarray;
 
@@ -185,10 +186,10 @@ enum Position { M_AUTOMATIC, M_TOP , M_BOTTOM , M_LEFT, M_RIGHT};
 enum VerticalAlign { MNORMAL, MTOP, MCAP, MHALF, MBASE, MBOTTOM };
 //enum VerticalAlign { MBASE, MTOP, MHALF, MBOTTOM };   // if change you need to change also share/magics/PostScriptMacros2.dat
 enum Shading { M_SH_NONE, M_SH_SOLID, M_SH_HATCH, M_SH_DOT };
-enum ArrowPosition { M_TAIL, M_CENTRE };
+enum ArrowPosition { M_TAIL, M_CENTRE, M_HEAD_ONLY};
 enum DisplayType { ABSOLUTE, INLINE, BLOCK, NONE, HIDDEN };
 enum ListPolicy { M_LASTONE, M_CYCLE };
-enum GraphicsFormat {PS, EPS, PDF, SVG, KML, PNG, X, CPS, CSVG, GIF, AGIF, JPG, QT};
+enum GraphicsFormat {PS, EPS, PDF, SVG, KML, PNG, X, CPS, CSVG, GIF, AGIF, JPG, QT, GEOJSON};
 enum AxisAutomaticSetting {m_off, m_both, m_min_only, m_max_only};
 
 /*
