@@ -31,9 +31,11 @@
 #include <map>
 #include <set>
 
-#include "odblib/odb_api.h"
+#include <odb_api/ColumnType.h>
+#include <odb_api/Reader.h>
+
 extern "C" {
-#include "odblib/odbcapi.h"
+#include <odb_api/odbcapi.h>
 }
 
 
@@ -43,14 +45,13 @@ extern "C" {
 #include "SciMethods.h"
 #include "TextVisitor.h"
 
-#include "odblib/Reader.h"
 
 static int getOdbColumnIndex(odb::Reader::iterator &,const string&);
 
 int getOdbColumnIndex(odb::Reader::iterator &firstRowIt,const string& colName)
 {
 	int index=0;
-  	for(odb::MetaData::iterator it=firstRowIt->columns().begin(); it != firstRowIt->columns().end(); ++it)
+  	for(odb::MetaData::const_iterator it=firstRowIt->columns().begin(); it != firstRowIt->columns().end(); ++it)
 	{			
 		string s=(*it)->name();
 		if(s == colName)
@@ -291,10 +292,13 @@ void OdaGeoDecoder:: visit(TextVisitor& title)
 	{
 		ostringstream text;
 		if ( !info("stats::min").empty() && !info("stats::max").empty() ) {
-			text  << "Min: " << info("stats::min") << " Max: " << info("stats::max") << " (" <<  size() << " points)";
+			text  << "Min: " << info("stats::min") << " Max: " << info("stats::max") << " (" << info("stats::points") << " points)";
 		}
-		else
-			text << size() << " points";
+		else {
+			string pts = info("stats::points").empty() ? "0" : info("stats::points");
+			text << pts << " points";
+		}
+
 		title.addAutomaticTitle(text.str());
 	}
 	else if (info("stats::points").empty())
