@@ -73,7 +73,7 @@ public:
     virtual int rightIndex(double) {  return -1; }
     virtual CellArray* array(MatrixHandler& matrix, IntervalMap<int>& range,
        		const Transformation& transformation, int width, int height,
-       		float resolution, const string& technique) { assert(0); return 0;}
+       		float resolution, const string& technique) { ASSERT(0); return 0;}
     virtual bool needClipping() { return false; }
     virtual bool method(ContourMethod*) { return false; }
 protected:
