@@ -1,7 +1,7 @@
 #
 # Package name and versioning information for Magics
 #
-MAGICS_PACKAGE_NAME='Magics'
+MAGICS_PACKAGE_NAME='MagicsNew'
 MAGICS_PACKAGE_VERSION='2.20.2'
 MAGICS_PACKAGE_COPYRIGHT_YEAR='2013'
 MAGICS_PACKAGE_COPYRIGHT_PERIOD='2007-2013'
